@@ -417,16 +417,10 @@ class PluginsManager(Protocol):  # todo: add methods
     pass
 
 
-# event emitter
-# @runtime_checkable
-# class EventEmitter(Protocol):
-#     def on(self, event: str, listener: Callback) -> None: ...
-#     def once(self, event: str, listener: Callback) -> None: ...
-#     def emit(self, event: str, *args: Any, **kwargs: Any) -> None: ...
-#     def remove_listener(self, event: str, listener: Callback) -> None: ...
-
-
 # plugin api
+EventType = Literal["finishLaunching", "shutdown"]
+
+
 @runtime_checkable
 class PluginAPI(Protocol):
     storage_path: str
@@ -437,6 +431,11 @@ class PluginAPI(Protocol):
     system_manager: SystemManager
     plugins_manager: PluginsManager
 
+    def on(self, event: EventType, listener: Callable) -> "PluginAPI": ...
+    def once(self, event: EventType, listener: Callable) -> "PluginAPI": ...
+    def remove_listener(self, event: EventType, listener: Callable) -> "PluginAPI": ...
+    def remove_all_listeners(self, event: EventType) -> "PluginAPI": ...
+
 
 # base plugin
 class BasePlugin(ABC):
